@@ -59,8 +59,7 @@ read_emigration <- function(year = 2010,
   if(is.null(local_file)) { return(NULL) }
 
   ### read data
-  df <- try(arrow::open_dataset(local_file), silent=FALSE)
-  check_parquet_file(df)
+  df <- arrow_open_dataset(local_file)
 
   ### Select
   if (!is.null(columns)) { # columns <- c('V0002','V0011')
