@@ -54,8 +54,7 @@ read_population <- function(year = 2010,
 
 
   ### read data
-  df <- try(arrow::open_dataset(local_file), silent=FALSE)
-  check_parquet_file(df)
+  df <- arrow_open_dataset(local_file)
 
   ### Select
   if (!is.null(columns)) { # columns <- c('V0002','V0011')
